/***************************************************************************
 * jtalk -- talk-like Jabber client
 * (C) Nicolas George - 2006
 * jtalk.h: common header
 ***************************************************************************/

/*
  This file is part of jtalk.

  jtalk is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  jtalk is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with jtalk; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdint.h>
#include <glib.h>

/* 1000 * unix time */
typedef uint_least64_t jtalk_timestamp_t;

typedef struct jtalk_connection_s jtalk_connection_t;

typedef struct jtalk_contact_s jtalk_contact_t;
typedef struct jtalk_message_s jtalk_message_t;

struct jtalk_contact_s {
    char *jid;
    char *short_name;
    GList *msg_first, *msg_last;
    char *log_file_name;
};

struct jtalk_message_s {
    jtalk_message_t *all_next, *all_prev;
    jtalk_timestamp_t timestamp;
    jtalk_contact_t *from;
    GSList *to;
    char *resource;
    char text[0];
};

typedef struct {
    unsigned char *buffer;
    size_t buffer_size, buffer_have;
    int fd;
    guint source_id;
} jtalk_client_t;

/* main.c */
extern jtalk_timestamp_t jtalk_now(void);
extern void jtalk_client_init(jtalk_client_t *);
extern void jtalk_line_from_client(jtalk_client_t *, unsigned char *);
extern void jtalk_got_chat_text(jtalk_connection_t *, const char *,
    const char *);
extern void jtalk_command_from_client(jtalk_client_t *, unsigned char *);
extern void jtalk_client_closed(jtalk_client_t *);

/* loudmouth.c */
extern jtalk_connection_t *jtalk_connection_new(char **, int);
extern void jtalk_connection_send_chat_message(jtalk_connection_t *,
    jtalk_contact_t *, char *);

/* socket.c */
extern void socket_server_start(void);
extern void socket_write(jtalk_client_t *, const char *);

/* settings.c */
extern const char *jtalk_user;
extern const char *jtalk_esc_reset;
extern const char *jtalk_esc_error;
extern const char *jtalk_esc_name;
extern const char *jtalk_esc_self_name;
const size_t jtalk_opt_max_history;
extern void jtalk_settings_init(void);
extern char *jtalk_settings_get_file(const char *);

/* terminal.c */
extern void jtalk_tell_user(const char *, ...);

/* contacts.c */
extern void jtalk_contact_init(void);
extern jtalk_contact_t *jtalk_contact_find(const char *, int);
extern jtalk_message_t *jtalk_message_new(const char *, const char *);
extern void jtalk_contact_add_message(jtalk_contact_t *, jtalk_message_t *);

/* log.c */
extern char *jtalk_log_file_name(jtalk_contact_t *);
extern void jtalk_log_message(jtalk_message_t *);
